==> react-genomix-1.1.0.tgz: package/es/hooks/use-local-storage.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

import { useEffect, useState } from 'react';

var setItem = function setItem(key, value) {
  if (!['string'].includes(typeof value === 'undefined' ? 'undefined' : _typeof(value))) {
    localStorage.setItem(key, JSON.stringify(value));
  } else {
    localStorage.setItem(key, value);
  }
};

var getItem = function getItem(key) {
  var item = localStorage.getItem(key);
  try {
    return JSON.parse(item);
  } catch (error) {
    return item;
  }
};

export var useLocalStorage = function useLocalStorage(key, defaultValue) {
  var _useState = useState(function () {
    var item = getItem(key);
    if (item) {
      return item;
    } else {
      setItem(key, defaultValue);
      return defaultValue;
    }
  }),
      state = _useState[0],
      setState = _useState[1];

  var setValue = function setValue(value) {
    if ((typeof value === 'undefined' ? 'undefined' : _typeof(value)) === 'object' && (typeof state === 'undefined' ? 'undefined' : _typeof(state)) === 'object') {
      setState(_extends({}, state, value));
      setItem(key, _extends({}, state, value));
    } else {
      setState(value);
      setItem(key, value);
    }
  };

  var localStorageChanged = function localStorageChanged(e) {
    if (e.key === key) {
      var value = void 0;
      try {
        value = JSON.parse(e.newValue);
      } catch (e) {
        value = e.newValue;
      }

      var newValue = void 0;
      if ((typeof value === 'undefined' ? 'undefined' : _typeof(value)) === 'object' && (typeof state === 'undefined' ? 'undefined' : _typeof(state)) === 'object') {
        newValue = _extends({}, state, value);
      } else {
        newValue = value;
      }
      setState(newValue);
    }
  };

  useEffect(function () {
    window.addEventListener('storage', localStorageChanged);

    return function () {
      window.removeEventListener('storage', localStorageChanged);
    };
  });

  useEffect(function () {
    setState(getItem(key));
  }, [key]);

  return [state, setValue];
};

export default useLocalStorage;

==> react-genomix-1.3.0.tgz: package/es/hooks/use-local-storage.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { useEffect, useState } from 'react';

var setItem = function setItem(key, value) {
  if (!['string'].includes(typeof value)) {
    localStorage.setItem(key, JSON.stringify(value));
  } else {
    localStorage.setItem(key, value);
  }
};

var getItem = function getItem(key) {
  var item = localStorage.getItem(key);

  try {
    return JSON.parse(item);
  } catch (error) {
    return item;
  }
};

export var useLocalStorage = function useLocalStorage(key, defaultValue) {
  var _useState = useState(function () {
    var item = getItem(key);

    if (item) {
      return item;
    } else {
      setItem(key, defaultValue);
      return defaultValue;
    }
  }),
      state = _useState[0],
      setState = _useState[1];

  var setValue = function setValue(value) {
    if (typeof value === 'object' && typeof state === 'object') {
      setState(_extends({}, state, {}, value));
      setItem(key, _extends({}, state, {}, value));
    } else {
      setState(value);
      setItem(key, value);
    }
  };

  var localStorageChanged = function localStorageChanged(e) {
    if (e.key === key) {
      var value;

      try {
        value = JSON.parse(e.newValue);
      } catch (e) {
        value = e.newValue;
      }

      var newValue;

      if (typeof value === 'object' && typeof state === 'object') {
        newValue = _extends({}, state, {}, value);
      } else {
        newValue = value;
      }

      setState(newValue);
    }
  };

  useEffect(function () {
    window.addEventListener('storage', localStorageChanged);
    return function () {
      window.removeEventListener('storage', localStorageChanged);
    };
  });
  useEffect(function () {
    setState(getItem(key));
  }, [key]);
  return [state, setValue];
};
export default useLocalStorage;
